@@ -64,12 +64,12 @@
  *
  * If your source file is @c program.cc, you can compile it with:
  * @code
- * g++ program.cc -o program  `pkg-config --cflags --libs gtkmm-2.4`
+ * g++ program.cc -o program  `pkg-config --cflags --libs gtkmm-3.0`
  * @endcode
  *
  * Alternatively, if using autoconf, use the following in @c configure.ac:
  * @code
- * PKG_CHECK_MODULES([GTKMM], [gtkmm-2.4])
+ * PKG_CHECK_MODULES([GTKMM], [gtkmm-3.0])
  * @endcode
  * Then use the generated @c GTKMM_CFLAGS and @c GTKMM_LIBS variables in the
  * project @c Makefile.am files. For example:
@@ -86,14 +86,19 @@ extern const int gtkmm_micro_version;
 
 #include <glibmm.h>
 #include <giomm.h>
+
+#include <gdkmm/dragcontext.h> //TODO: Remove this. It works around a strange compilation problem with Cairo::Surface in the tests.
+
 #include <gdkmm.h>
 
+
 #include <gtkmm/object.h>
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/accelkey.h>
 #include <gtkmm/accelgroup.h>
 #include <gtkmm/adjustment.h>
 #include <gtkmm/alignment.h>
+#include <gtkmm/application.h>
 #include <gtkmm/arrow.h>
 #include <gtkmm/aspectframe.h>
 #include <gtkmm/assistant.h>
@@ -118,13 +123,9 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/cellrenderertoggle.h>
 #include <gtkmm/colorbutton.h>
 #include <gtkmm/colorselection.h>
-#include <gtkmm/combo.h> //TODO: Deprecated.
 #include <gtkmm/combobox.h>
-#include <gtkmm/comboboxentry.h>
-#include <gtkmm/comboboxentrytext.h>
 #include <gtkmm/comboboxtext.h>
 #include <gtkmm/container.h>
-#include <gtkmm/curve.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/drawingarea.h>
 #include <gtkmm/editable.h>
@@ -137,7 +138,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/filechooserdialog.h>
 #include <gtkmm/filechooserwidget.h>
 #include <gtkmm/filefilter.h>
-#include <gtkmm/fileselection.h> //TODO: Deprecated.
 #include <gtkmm/fixed.h>
 #include <gtkmm/fontbutton.h>
 #include <gtkmm/fontselection.h>
@@ -152,8 +152,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/image.h>
 #include <gtkmm/imagemenuitem.h>
 #include <gtkmm/infobar.h>
-#include <gtkmm/inputdialog.h>
-#include <gtkmm/item.h>
 #include <gtkmm/calendar.h>
 #include <gtkmm/invisible.h>
 #include <gtkmm/label.h>
@@ -163,7 +161,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/linkbutton.h>
 #include <gtkmm/main.h>
 #include <gtkmm/menu.h>
-#include <gtkmm/menu_elems.h>
 #include <gtkmm/menubar.h>
 #include <gtkmm/menuitem.h>
 #include <gtkmm/menushell.h>
@@ -172,7 +169,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/notebook.h>
 #include <gtkmm/object.h>
 #include <gtkmm/offscreenwindow.h>
-#include <gtkmm/optionmenu.h>
 #include <gtkmm/paned.h>
 #include <gtkmm/pagesetup.h>
 #ifndef G_OS_WIN32
@@ -239,7 +235,6 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/toggletoolbutton.h>
 #include <gtkmm/menutoolbutton.h>
 #include <gtkmm/tooltip.h>
-#include <gtkmm/tooltips.h>
 #include <gtkmm/treemodel.h>
 #include <gtkmm/treemodelfilter.h>
 #include <gtkmm/treemodelsort.h>
