@@ -20,11 +20,14 @@
 #include "activatable.h"
 #include "adjustment.h"
 #include "alignment.h"
+#include "application.h"
 #include "arrow.h"
 #include "aspectframe.h"
 #include "assistant.h"
 #include "bin.h"
+#include "border.h"
 #include "box.h"
+#include "buildable.h"
 #include "builder.h"
 #include "button.h"
 #include "buttonbox.h"
@@ -47,7 +50,7 @@
 #include "colorbutton.h"
 #include "colorselection.h"
 #include "combobox.h"
-#include "comboboxentry.h"
+#include "comboboxtext.h"
 #include "container.h"
 #include "dialog.h"
 #include "drawingarea.h"
@@ -63,7 +66,6 @@
 #include "filechooserdialog.h"
 #include "filechooserwidget.h"
 #include "filefilter.h"
-#include "fileselection.h"
 #include "fixed.h"
 #include "fontbutton.h"
 #include "fontselection.h"
@@ -79,7 +81,6 @@
 #include "imagemenuitem.h"
 #include "infobar.h"
 #include "invisible.h"
-#include "item.h"
 #include "label.h"
 #include "layout.h"
 #include "linkbutton.h"
@@ -93,9 +94,7 @@
 #include "messagedialog.h"
 #include "misc.h"
 #include "notebook.h"
-#include "object.h"
 #include "offscreenwindow.h"
-#include "optionmenu.h"
 #include "orientable.h"
 #include "pagesetup.h"
 #include "paned.h"
@@ -120,9 +119,11 @@
 #include "recentfilter.h"
 #include "recentinfo.h"
 #include "recentmanager.h"
+#include "requisition.h"
 #include "ruler.h"
 #include "scale.h"
 #include "scalebutton.h"
+#include "scrollable.h"
 #include "scrollbar.h"
 #include "scrolledwindow.h"
 #include "selectiondata.h"
@@ -159,7 +160,6 @@
 #include "toolpalette.h"
 #include "toolshell.h"
 #include "tooltip.h"
-#include "tooltips.h"
 #include "treedragdest.h"
 #include "treedragsource.h"
 #include "treeiter.h"
@@ -182,9 +182,6 @@
 #include "printer.h"
 #include "printjob.h"
 #include "printunixdialog.h"
-#include "combo.h"
-#include "curve.h"
-#include "inputdialog.h"
 
 extern "C"
 {
@@ -198,6 +195,7 @@ GType gtk_action_get_type(void);
 GType gtk_action_group_get_type(void);
 GType gtk_adjustment_get_type(void);
 GType gtk_alignment_get_type(void);
+GType gtk_application_get_type(void);
 GType gtk_arrow_get_type(void);
 GType gtk_aspect_frame_get_type(void);
 GType gtk_assistant_get_type(void);
@@ -223,21 +221,9 @@ GType gtk_clipboard_get_type(void);
 GType gtk_color_button_get_type(void);
 GType gtk_color_selection_get_type(void);
 GType gtk_color_selection_dialog_get_type(void);
-#ifndef GTKMM_DISABLE_DEPRECATED
-GType gtk_combo_get_type(void);
-#endif // *_DISABLE_DEPRECATED
 GType gtk_combo_box_get_type(void);
-GType gtk_combo_box_entry_get_type(void);
-#ifndef GTKMM_DISABLE_DEPRECATED
-GType gtk_list_get_type(void);
-#endif // *_DISABLE_DEPRECATED
-#ifndef GTKMM_DISABLE_DEPRECATED
-GType gtk_list_item_get_type(void);
-#endif // *_DISABLE_DEPRECATED
+GType gtk_combo_box_text_get_type(void);
 GType gtk_container_get_type(void);
-#ifndef GTKMM_DISABLE_DEPRECATED
-GType gtk_curve_get_type(void);
-#endif // *_DISABLE_DEPRECATED
 GType gtk_dialog_get_type(void);
 GType gtk_drawing_area_get_type(void);
 GType gtk_entry_get_type(void);
@@ -249,15 +235,11 @@ GType gtk_file_chooser_button_get_type(void);
 GType gtk_file_chooser_dialog_get_type(void);
 GType gtk_file_chooser_widget_get_type(void);
 GType gtk_file_filter_get_type(void);
-#ifndef GTKMM_DISABLE_DEPRECATED
-GType gtk_file_selection_get_type(void);
-#endif // *_DISABLE_DEPRECATED
 GType gtk_fixed_get_type(void);
 GType gtk_font_button_get_type(void);
 GType gtk_font_selection_get_type(void);
 GType gtk_font_selection_dialog_get_type(void);
 GType gtk_frame_get_type(void);
-GType gtk_gamma_curve_get_type(void);
 GType gtk_hbox_get_type(void);
 GType gtk_hbutton_box_get_type(void);
 GType gtk_hpaned_get_type(void);
@@ -272,11 +254,7 @@ GType gtk_icon_view_get_type(void);
 GType gtk_image_get_type(void);
 GType gtk_image_menu_item_get_type(void);
 GType gtk_info_bar_get_type(void);
-#ifndef GTKMM_DISABLE_DEPRECATED
-GType gtk_input_dialog_get_type(void);
-#endif // *_DISABLE_DEPRECATED
 GType gtk_invisible_get_type(void);
-GType gtk_item_get_type(void);
 GType gtk_label_get_type(void);
 GType gtk_layout_get_type(void);
 GType gtk_link_button_get_type(void);
@@ -289,11 +267,7 @@ GType gtk_menu_tool_button_get_type(void);
 GType gtk_message_dialog_get_type(void);
 GType gtk_misc_get_type(void);
 GType gtk_notebook_get_type(void);
-GType gtk_object_get_type(void);
 GType gtk_offscreen_window_get_type(void);
-#ifndef GTKMM_DISABLE_DEPRECATED
-GType gtk_option_menu_get_type(void);
-#endif // *_DISABLE_DEPRECATED
 GType gtk_page_setup_get_type(void);
 #ifndef G_OS_WIN32
 GType gtk_page_setup_unix_dialog_get_type(void);
@@ -362,9 +336,6 @@ GType gtk_tool_item_group_get_type(void);
 GType gtk_tool_palette_get_type(void);
 GType gtk_toolbar_get_type(void);
 GType gtk_tooltip_get_type(void);
-#ifndef GTKMM_DISABLE_DEPRECATED
-GType gtk_tooltips_get_type(void);
-#endif // *_DISABLE_DEPRECATED
 GType gtk_tree_model_filter_get_type(void);
 GType gtk_tree_model_sort_get_type(void);
 GType gtk_tree_selection_get_type(void);
@@ -405,6 +376,7 @@ namespace Gtk {  class Action_Class { public: static Glib::ObjectBase* wrap_new(
 namespace Gtk {  class ActionGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Adjustment_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Alignment_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gtk {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Arrow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AspectFrame_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Assistant_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -430,21 +402,9 @@ namespace Gtk {  class Clipboard_Class { public: static Glib::ObjectBase* wrap_n
 namespace Gtk {  class ColorButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class ColorSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class ColorSelectionDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#ifndef GTKMM_DISABLE_DEPRECATED
-namespace Gtk {  class Combo_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif // *_DISABLE_DEPRECATED
 namespace Gtk {  class ComboBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gtk {  class ComboBoxEntry_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#ifndef GTKMM_DISABLE_DEPRECATED
-namespace Gtk {  class ComboDropDown_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif // *_DISABLE_DEPRECATED
-#ifndef GTKMM_DISABLE_DEPRECATED
-namespace Gtk {  class ComboDropDownItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif // *_DISABLE_DEPRECATED
+namespace Gtk {  class ComboBoxText_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Container_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#ifndef GTKMM_DISABLE_DEPRECATED
-namespace Gtk {  class Curve_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif // *_DISABLE_DEPRECATED
 namespace Gtk {  class Dialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class DrawingArea_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Entry_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -456,15 +416,11 @@ namespace Gtk {  class FileChooserButton_Class { public: static Glib::ObjectBase
 namespace Gtk {  class FileChooserDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class FileChooserWidget_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class FileFilter_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#ifndef GTKMM_DISABLE_DEPRECATED
-namespace Gtk {  class FileSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif // *_DISABLE_DEPRECATED
 namespace Gtk {  class Fixed_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class FontButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class FontSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class FontSelectionDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Frame_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gtk {  class GammaCurve_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class HBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class HButtonBox_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class HPaned_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -479,11 +435,7 @@ namespace Gtk {  class IconView_Class { public: static Glib::ObjectBase* wrap_ne
 namespace Gtk {  class Image_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class ImageMenuItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class InfoBar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#ifndef GTKMM_DISABLE_DEPRECATED
-namespace Gtk {  class InputDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif // *_DISABLE_DEPRECATED
 namespace Gtk {  class Invisible_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gtk {  class Item_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Label_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Layout_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class LinkButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -496,11 +448,7 @@ namespace Gtk {  class MenuToolButton_Class { public: static Glib::ObjectBase* w
 namespace Gtk {  class MessageDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Misc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Notebook_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gtk {  class Object_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class OffscreenWindow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#ifndef GTKMM_DISABLE_DEPRECATED
-namespace Gtk {  class OptionMenu_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif // *_DISABLE_DEPRECATED
 namespace Gtk {  class PageSetup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef G_OS_WIN32
 namespace Gtk {  class PageSetupUnixDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -569,9 +517,6 @@ namespace Gtk {  class ToolItemGroup_Class { public: static Glib::ObjectBase* wr
 namespace Gtk {  class ToolPalette_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Toolbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Tooltip_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#ifndef GTKMM_DISABLE_DEPRECATED
-namespace Gtk {  class Tooltips_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-#endif // *_DISABLE_DEPRECATED
 namespace Gtk {  class TreeModelFilter_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class TreeModelSort_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class TreeSelection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -612,6 +557,7 @@ void wrap_init()
   Glib::wrap_register(gtk_action_group_get_type(), &Gtk::ActionGroup_Class::wrap_new);
   Glib::wrap_register(gtk_adjustment_get_type(), &Gtk::Adjustment_Class::wrap_new);
   Glib::wrap_register(gtk_alignment_get_type(), &Gtk::Alignment_Class::wrap_new);
+  Glib::wrap_register(gtk_application_get_type(), &Gtk::Application_Class::wrap_new);
   Glib::wrap_register(gtk_arrow_get_type(), &Gtk::Arrow_Class::wrap_new);
   Glib::wrap_register(gtk_aspect_frame_get_type(), &Gtk::AspectFrame_Class::wrap_new);
   Glib::wrap_register(gtk_assistant_get_type(), &Gtk::Assistant_Class::wrap_new);
@@ -637,21 +583,9 @@ void wrap_init()
   Glib::wrap_register(gtk_color_button_get_type(), &Gtk::ColorButton_Class::wrap_new);
   Glib::wrap_register(gtk_color_selection_get_type(), &Gtk::ColorSelection_Class::wrap_new);
   Glib::wrap_register(gtk_color_selection_dialog_get_type(), &Gtk::ColorSelectionDialog_Class::wrap_new);
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Glib::wrap_register(gtk_combo_get_type(), &Gtk::Combo_Class::wrap_new);
-#endif // *_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_combo_box_get_type(), &Gtk::ComboBox_Class::wrap_new);
-  Glib::wrap_register(gtk_combo_box_entry_get_type(), &Gtk::ComboBoxEntry_Class::wrap_new);
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Glib::wrap_register(gtk_list_get_type(), &Gtk::ComboDropDown_Class::wrap_new);
-#endif // *_DISABLE_DEPRECATED
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Glib::wrap_register(gtk_list_item_get_type(), &Gtk::ComboDropDownItem_Class::wrap_new);
-#endif // *_DISABLE_DEPRECATED
+  Glib::wrap_register(gtk_combo_box_text_get_type(), &Gtk::ComboBoxText_Class::wrap_new);
   Glib::wrap_register(gtk_container_get_type(), &Gtk::Container_Class::wrap_new);
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Glib::wrap_register(gtk_curve_get_type(), &Gtk::Curve_Class::wrap_new);
-#endif // *_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_dialog_get_type(), &Gtk::Dialog_Class::wrap_new);
   Glib::wrap_register(gtk_drawing_area_get_type(), &Gtk::DrawingArea_Class::wrap_new);
   Glib::wrap_register(gtk_entry_get_type(), &Gtk::Entry_Class::wrap_new);
@@ -663,15 +597,11 @@ void wrap_init()
   Glib::wrap_register(gtk_file_chooser_dialog_get_type(), &Gtk::FileChooserDialog_Class::wrap_new);
   Glib::wrap_register(gtk_file_chooser_widget_get_type(), &Gtk::FileChooserWidget_Class::wrap_new);
   Glib::wrap_register(gtk_file_filter_get_type(), &Gtk::FileFilter_Class::wrap_new);
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Glib::wrap_register(gtk_file_selection_get_type(), &Gtk::FileSelection_Class::wrap_new);
-#endif // *_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_fixed_get_type(), &Gtk::Fixed_Class::wrap_new);
   Glib::wrap_register(gtk_font_button_get_type(), &Gtk::FontButton_Class::wrap_new);
   Glib::wrap_register(gtk_font_selection_get_type(), &Gtk::FontSelection_Class::wrap_new);
   Glib::wrap_register(gtk_font_selection_dialog_get_type(), &Gtk::FontSelectionDialog_Class::wrap_new);
   Glib::wrap_register(gtk_frame_get_type(), &Gtk::Frame_Class::wrap_new);
-  Glib::wrap_register(gtk_gamma_curve_get_type(), &Gtk::GammaCurve_Class::wrap_new);
   Glib::wrap_register(gtk_hbox_get_type(), &Gtk::HBox_Class::wrap_new);
   Glib::wrap_register(gtk_hbutton_box_get_type(), &Gtk::HButtonBox_Class::wrap_new);
   Glib::wrap_register(gtk_hpaned_get_type(), &Gtk::HPaned_Class::wrap_new);
@@ -686,11 +616,7 @@ void wrap_init()
   Glib::wrap_register(gtk_image_get_type(), &Gtk::Image_Class::wrap_new);
   Glib::wrap_register(gtk_image_menu_item_get_type(), &Gtk::ImageMenuItem_Class::wrap_new);
   Glib::wrap_register(gtk_info_bar_get_type(), &Gtk::InfoBar_Class::wrap_new);
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Glib::wrap_register(gtk_input_dialog_get_type(), &Gtk::InputDialog_Class::wrap_new);
-#endif // *_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_invisible_get_type(), &Gtk::Invisible_Class::wrap_new);
-  Glib::wrap_register(gtk_item_get_type(), &Gtk::Item_Class::wrap_new);
   Glib::wrap_register(gtk_label_get_type(), &Gtk::Label_Class::wrap_new);
   Glib::wrap_register(gtk_layout_get_type(), &Gtk::Layout_Class::wrap_new);
   Glib::wrap_register(gtk_link_button_get_type(), &Gtk::LinkButton_Class::wrap_new);
@@ -703,11 +629,7 @@ void wrap_init()
   Glib::wrap_register(gtk_message_dialog_get_type(), &Gtk::MessageDialog_Class::wrap_new);
   Glib::wrap_register(gtk_misc_get_type(), &Gtk::Misc_Class::wrap_new);
   Glib::wrap_register(gtk_notebook_get_type(), &Gtk::Notebook_Class::wrap_new);
-  Glib::wrap_register(gtk_object_get_type(), &Gtk::Object_Class::wrap_new);
   Glib::wrap_register(gtk_offscreen_window_get_type(), &Gtk::OffscreenWindow_Class::wrap_new);
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Glib::wrap_register(gtk_option_menu_get_type(), &Gtk::OptionMenu_Class::wrap_new);
-#endif // *_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_page_setup_get_type(), &Gtk::PageSetup_Class::wrap_new);
 #ifndef G_OS_WIN32
   Glib::wrap_register(gtk_page_setup_unix_dialog_get_type(), &Gtk::PageSetupUnixDialog_Class::wrap_new);
@@ -776,9 +698,6 @@ void wrap_init()
   Glib::wrap_register(gtk_tool_palette_get_type(), &Gtk::ToolPalette_Class::wrap_new);
   Glib::wrap_register(gtk_toolbar_get_type(), &Gtk::Toolbar_Class::wrap_new);
   Glib::wrap_register(gtk_tooltip_get_type(), &Gtk::Tooltip_Class::wrap_new);
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Glib::wrap_register(gtk_tooltips_get_type(), &Gtk::Tooltips_Class::wrap_new);
-#endif // *_DISABLE_DEPRECATED
   Glib::wrap_register(gtk_tree_model_filter_get_type(), &Gtk::TreeModelFilter_Class::wrap_new);
   Glib::wrap_register(gtk_tree_model_sort_get_type(), &Gtk::TreeModelSort_Class::wrap_new);
   Glib::wrap_register(gtk_tree_selection_get_type(), &Gtk::TreeSelection_Class::wrap_new);
@@ -807,6 +726,7 @@ void wrap_init()
   Gtk::ActionGroup::get_type();
   Gtk::Adjustment::get_type();
   Gtk::Alignment::get_type();
+  Gtk::Application::get_type();
   Gtk::Arrow::get_type();
   Gtk::AspectFrame::get_type();
   Gtk::Assistant::get_type();
@@ -832,21 +752,9 @@ void wrap_init()
   Gtk::ColorButton::get_type();
   Gtk::ColorSelection::get_type();
   Gtk::ColorSelectionDialog::get_type();
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Gtk::Combo::get_type();
-#endif // *_DISABLE_DEPRECATED
   Gtk::ComboBox::get_type();
-  Gtk::ComboBoxEntry::get_type();
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Gtk::ComboDropDown::get_type();
-#endif // *_DISABLE_DEPRECATED
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Gtk::ComboDropDownItem::get_type();
-#endif // *_DISABLE_DEPRECATED
+  Gtk::ComboBoxText::get_type();
   Gtk::Container::get_type();
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Gtk::Curve::get_type();
-#endif // *_DISABLE_DEPRECATED
   Gtk::Dialog::get_type();
   Gtk::DrawingArea::get_type();
   Gtk::Entry::get_type();
@@ -858,15 +766,11 @@ void wrap_init()
   Gtk::FileChooserDialog::get_type();
   Gtk::FileChooserWidget::get_type();
   Gtk::FileFilter::get_type();
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Gtk::FileSelection::get_type();
-#endif // *_DISABLE_DEPRECATED
   Gtk::Fixed::get_type();
   Gtk::FontButton::get_type();
   Gtk::FontSelection::get_type();
   Gtk::FontSelectionDialog::get_type();
   Gtk::Frame::get_type();
-  Gtk::GammaCurve::get_type();
   Gtk::HBox::get_type();
   Gtk::HButtonBox::get_type();
   Gtk::HPaned::get_type();
@@ -881,11 +785,7 @@ void wrap_init()
   Gtk::Image::get_type();
   Gtk::ImageMenuItem::get_type();
   Gtk::InfoBar::get_type();
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Gtk::InputDialog::get_type();
-#endif // *_DISABLE_DEPRECATED
   Gtk::Invisible::get_type();
-  Gtk::Item::get_type();
   Gtk::Label::get_type();
   Gtk::Layout::get_type();
   Gtk::LinkButton::get_type();
@@ -898,11 +798,7 @@ void wrap_init()
   Gtk::MessageDialog::get_type();
   Gtk::Misc::get_type();
   Gtk::Notebook::get_type();
-  Gtk::Object::get_type();
   Gtk::OffscreenWindow::get_type();
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Gtk::OptionMenu::get_type();
-#endif // *_DISABLE_DEPRECATED
   Gtk::PageSetup::get_type();
 #ifndef G_OS_WIN32
   Gtk::PageSetupUnixDialog::get_type();
@@ -971,9 +867,6 @@ void wrap_init()
   Gtk::ToolPalette::get_type();
   Gtk::Toolbar::get_type();
   Gtk::Tooltip::get_type();
-#ifndef GTKMM_DISABLE_DEPRECATED
-  Gtk::Tooltips::get_type();
-#endif // *_DISABLE_DEPRECATED
   Gtk::TreeModelFilter::get_type();
   Gtk::TreeModelSort::get_type();
   Gtk::TreeSelection::get_type();
